M = Manifold(2, 'M')
X = M.chart('x y'); x, y = X[:]
v = M.vector_field(-y, x, name='v')
g = v.plot(max_range=4, number_values=5, scale=0.5)
sphinx_plot(g)